@@ -10,6 +10,7 @@
 #ifndef APK_DEFINES_H
 #define APK_DEFINES_H
 
+#include <assert.h>
 #include <endian.h>
 #include <stdint.h>
 #include <string.h>
@@ -38,6 +39,7 @@
 #define EAPKDEPFORMAT		1027
 #define EAPKDBFORMAT		1028
 #define EAPKCACHE		1029
+#define EAPKCRYPTO		1030
 
 static inline void *ERR_PTR(long error) { return (void*) error; }
 static inline void *ERR_CAST(const void *ptr) { return (void*) ptr; }
